# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: elk_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x65lk_manager.proto\"\x12\n\x10StartLogstashMsg\"\x10\n\x0eStartKibanaMsg\"\x11\n\x0fStartElasticMsg\"\x11\n\x0fStopLogstashMsg\"\x0f\n\rStopKibanaMsg\"\x10\n\x0eStopElasticMsg\"\x0c\n\nStopElkMsg\"\r\n\x0bStartElkMsg\"\x11\n\x0fGetElkStatusMsg\"P\n\x06\x45lkDTO\x12\x16\n\x0e\x65lasticRunning\x18\x01 \x01(\x08\x12\x15\n\rkibanaRunning\x18\x02 \x01(\x08\x12\x17\n\x0flogstashRunning\x18\x03 \x01(\x08\x32\x89\x03\n\nElkManager\x12+\n\x0cgetElkStatus\x12\x10.GetElkStatusMsg\x1a\x07.ElkDTO\"\x00\x12!\n\x07stopElk\x12\x0b.StopElkMsg\x1a\x07.ElkDTO\"\x00\x12#\n\x08startElk\x12\x0c.StartElkMsg\x1a\x07.ElkDTO\"\x00\x12)\n\x0bstopElastic\x12\x0f.StopElasticMsg\x1a\x07.ElkDTO\"\x00\x12+\n\x0cstartElastic\x12\x10.StartElasticMsg\x1a\x07.ElkDTO\"\x00\x12+\n\x0cstopLogstash\x12\x10.StopLogstashMsg\x1a\x07.ElkDTO\"\x00\x12-\n\rstartLogstash\x12\x11.StartLogstashMsg\x1a\x07.ElkDTO\"\x00\x12\'\n\nstopKibana\x12\x0e.StopKibanaMsg\x1a\x07.ElkDTO\"\x00\x12)\n\x0bstartKibana\x12\x0f.StartKibanaMsg\x1a\x07.ElkDTO\"\x00\x62\x06proto3')



_STARTLOGSTASHMSG = DESCRIPTOR.message_types_by_name['StartLogstashMsg']
_STARTKIBANAMSG = DESCRIPTOR.message_types_by_name['StartKibanaMsg']
_STARTELASTICMSG = DESCRIPTOR.message_types_by_name['StartElasticMsg']
_STOPLOGSTASHMSG = DESCRIPTOR.message_types_by_name['StopLogstashMsg']
_STOPKIBANAMSG = DESCRIPTOR.message_types_by_name['StopKibanaMsg']
_STOPELASTICMSG = DESCRIPTOR.message_types_by_name['StopElasticMsg']
_STOPELKMSG = DESCRIPTOR.message_types_by_name['StopElkMsg']
_STARTELKMSG = DESCRIPTOR.message_types_by_name['StartElkMsg']
_GETELKSTATUSMSG = DESCRIPTOR.message_types_by_name['GetElkStatusMsg']
_ELKDTO = DESCRIPTOR.message_types_by_name['ElkDTO']
StartLogstashMsg = _reflection.GeneratedProtocolMessageType('StartLogstashMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTLOGSTASHMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartLogstashMsg)
  })
_sym_db.RegisterMessage(StartLogstashMsg)

StartKibanaMsg = _reflection.GeneratedProtocolMessageType('StartKibanaMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTKIBANAMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartKibanaMsg)
  })
_sym_db.RegisterMessage(StartKibanaMsg)

StartElasticMsg = _reflection.GeneratedProtocolMessageType('StartElasticMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTELASTICMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartElasticMsg)
  })
_sym_db.RegisterMessage(StartElasticMsg)

StopLogstashMsg = _reflection.GeneratedProtocolMessageType('StopLogstashMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPLOGSTASHMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopLogstashMsg)
  })
_sym_db.RegisterMessage(StopLogstashMsg)

StopKibanaMsg = _reflection.GeneratedProtocolMessageType('StopKibanaMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPKIBANAMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopKibanaMsg)
  })
_sym_db.RegisterMessage(StopKibanaMsg)

StopElasticMsg = _reflection.GeneratedProtocolMessageType('StopElasticMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPELASTICMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopElasticMsg)
  })
_sym_db.RegisterMessage(StopElasticMsg)

StopElkMsg = _reflection.GeneratedProtocolMessageType('StopElkMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPELKMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopElkMsg)
  })
_sym_db.RegisterMessage(StopElkMsg)

StartElkMsg = _reflection.GeneratedProtocolMessageType('StartElkMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTELKMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartElkMsg)
  })
_sym_db.RegisterMessage(StartElkMsg)

GetElkStatusMsg = _reflection.GeneratedProtocolMessageType('GetElkStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETELKSTATUSMSG,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetElkStatusMsg)
  })
_sym_db.RegisterMessage(GetElkStatusMsg)

ElkDTO = _reflection.GeneratedProtocolMessageType('ElkDTO', (_message.Message,), {
  'DESCRIPTOR' : _ELKDTO,
  '__module__' : 'elk_manager_pb2'
  # @@protoc_insertion_point(class_scope:ElkDTO)
  })
_sym_db.RegisterMessage(ElkDTO)

_ELKMANAGER = DESCRIPTOR.services_by_name['ElkManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STARTLOGSTASHMSG._serialized_start=21
  _STARTLOGSTASHMSG._serialized_end=39
  _STARTKIBANAMSG._serialized_start=41
  _STARTKIBANAMSG._serialized_end=57
  _STARTELASTICMSG._serialized_start=59
  _STARTELASTICMSG._serialized_end=76
  _STOPLOGSTASHMSG._serialized_start=78
  _STOPLOGSTASHMSG._serialized_end=95
  _STOPKIBANAMSG._serialized_start=97
  _STOPKIBANAMSG._serialized_end=112
  _STOPELASTICMSG._serialized_start=114
  _STOPELASTICMSG._serialized_end=130
  _STOPELKMSG._serialized_start=132
  _STOPELKMSG._serialized_end=144
  _STARTELKMSG._serialized_start=146
  _STARTELKMSG._serialized_end=159
  _GETELKSTATUSMSG._serialized_start=161
  _GETELKSTATUSMSG._serialized_end=178
  _ELKDTO._serialized_start=180
  _ELKDTO._serialized_end=260
  _ELKMANAGER._serialized_start=263
  _ELKMANAGER._serialized_end=656
# @@protoc_insertion_point(module_scope)
