# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: traffic_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15traffic_manager.proto\"\x10\n\x0eStopTrafficMsg\"6\n\x0fStartTrafficMsg\x12\x11\n\tsleepTime\x18\x01 \x01(\x05\x12\x10\n\x08\x63ommands\x18\x02 \x03(\t\"\x15\n\x13GetTrafficStatusMsg\"-\n\nTrafficDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06script\x18\x02 \x01(\t2\xa9\x01\n\x0eTrafficManager\x12\x37\n\x10getTrafficStatus\x12\x14.GetTrafficStatusMsg\x1a\x0b.TrafficDTO\"\x00\x12-\n\x0bstopTraffic\x12\x0f.StopTrafficMsg\x1a\x0b.TrafficDTO\"\x00\x12/\n\x0cstartTraffic\x12\x10.StartTrafficMsg\x1a\x0b.TrafficDTO\"\x00\x62\x06proto3')



_STOPTRAFFICMSG = DESCRIPTOR.message_types_by_name['StopTrafficMsg']
_STARTTRAFFICMSG = DESCRIPTOR.message_types_by_name['StartTrafficMsg']
_GETTRAFFICSTATUSMSG = DESCRIPTOR.message_types_by_name['GetTrafficStatusMsg']
_TRAFFICDTO = DESCRIPTOR.message_types_by_name['TrafficDTO']
StopTrafficMsg = _reflection.GeneratedProtocolMessageType('StopTrafficMsg', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRAFFICMSG,
  '__module__' : 'traffic_manager_pb2'
  # @@protoc_insertion_point(class_scope:StopTrafficMsg)
  })
_sym_db.RegisterMessage(StopTrafficMsg)

StartTrafficMsg = _reflection.GeneratedProtocolMessageType('StartTrafficMsg', (_message.Message,), {
  'DESCRIPTOR' : _STARTTRAFFICMSG,
  '__module__' : 'traffic_manager_pb2'
  # @@protoc_insertion_point(class_scope:StartTrafficMsg)
  })
_sym_db.RegisterMessage(StartTrafficMsg)

GetTrafficStatusMsg = _reflection.GeneratedProtocolMessageType('GetTrafficStatusMsg', (_message.Message,), {
  'DESCRIPTOR' : _GETTRAFFICSTATUSMSG,
  '__module__' : 'traffic_manager_pb2'
  # @@protoc_insertion_point(class_scope:GetTrafficStatusMsg)
  })
_sym_db.RegisterMessage(GetTrafficStatusMsg)

TrafficDTO = _reflection.GeneratedProtocolMessageType('TrafficDTO', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICDTO,
  '__module__' : 'traffic_manager_pb2'
  # @@protoc_insertion_point(class_scope:TrafficDTO)
  })
_sym_db.RegisterMessage(TrafficDTO)

_TRAFFICMANAGER = DESCRIPTOR.services_by_name['TrafficManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STOPTRAFFICMSG._serialized_start=25
  _STOPTRAFFICMSG._serialized_end=41
  _STARTTRAFFICMSG._serialized_start=43
  _STARTTRAFFICMSG._serialized_end=97
  _GETTRAFFICSTATUSMSG._serialized_start=99
  _GETTRAFFICSTATUSMSG._serialized_end=120
  _TRAFFICDTO._serialized_start=122
  _TRAFFICDTO._serialized_end=167
  _TRAFFICMANAGER._serialized_start=170
  _TRAFFICMANAGER._serialized_end=339
# @@protoc_insertion_point(module_scope)
